@@ -46,7 +46,14 @@
 #
 # END BPS TAGGED BLOCK }}}
 
+use strict;
+use warnings;
+
 package RT::I18N::ru;
+use base 'RT::I18N';
+
+use strict;
+use warnings;
 
 sub quant {
     my($handle, $num, @forms) = @_;
@@ -71,4 +78,6 @@ sub numerate {
     return $forms[$form];
 }
 
+RT::Base->_ImportOverlays();
+
 1;
