@@ -48,10 +48,10 @@
 
 package RT::Reminders;
 
-use base qw/RT::Base/;
-
-our $REMINDER_QUEUE = 'General';
+use strict;
+use warnings;
 
+use base 'RT::Base';
 
 sub new {
     my $class = shift;
@@ -61,7 +61,6 @@ sub new {
     return($self);
 }
 
-
 sub Ticket {
     my $self = shift;
     $self->{'_ticket'} = shift if (@_);
@@ -74,10 +73,9 @@ sub TicketObj {
         $self->{'_ticketobj'} = RT::Ticket->new($self->CurrentUser);
         $self->{'_ticketobj'}->Load($self->Ticket);
     }
-        return $self->{'_ticketobj'};
+    return $self->{'_ticketobj'};
 }
 
-
 =head2 Collection
 
 Returns an RT::Tickets object containing reminders for this object's "Ticket"
@@ -88,8 +86,8 @@ sub Collection {
     my $self = shift;
     my $col = RT::Tickets->new($self->CurrentUser);
 
-     my $query = 'Type = "reminder" AND RefersTo = "'.$self->Ticket.'"';
-   
+    my $query = 'Type = "reminder" AND RefersTo = "'.$self->Ticket.'"';
+
     $col->FromSQL($query);
 
     $col->OrderBy( FIELD => 'Due' );
@@ -107,55 +105,59 @@ Takes
     Owner
     Due
 
-
 =cut
 
-
 sub Add {
     my $self = shift;
-    my %args = ( Subject => undef,
-                 Owner => undef,
-                 Due => undef,
-                 @_);
+    my %args = (
+        Subject => undef,
+        Owner => undef,
+        Due => undef,
+        @_
+    );
 
     my $reminder = RT::Ticket->new($self->CurrentUser);
-    $reminder->Create( Subject => $args{'Subject'},
-                       Owner => $args{'Owner'},
-                       Due => $args{'Due'},
-                       RefersTo => $self->Ticket,
-                       Type => 'reminder',
-                       Queue => $self->TicketObj->Queue,
-                   
-                   );
-    $self->TicketObj->_NewTransaction(Type => 'AddReminder',
-                                    Field => 'RT::Ticket',
-                                   NewValue => $reminder->id);
-
-
+    my ( $status, $msg ) = $reminder->Create(
+        Subject => $args{'Subject'},
+        Owner => $args{'Owner'},
+        Due => $args{'Due'},
+        RefersTo => $self->Ticket,
+        Type => 'reminder',
+        Queue => $self->TicketObj->Queue,
+    );
+    $self->TicketObj->_NewTransaction(
+        Type => 'AddReminder',
+        Field => 'RT::Ticket',
+        NewValue => $reminder->id
+    ) if $status;
+    return ( $status, $msg );
 }
 
-
 sub Open {
     my $self = shift;
-    my $reminder = shift; 
+    my $reminder = shift;
 
-    $reminder->SetStatus('open');
-    $self->TicketObj->_NewTransaction(Type => 'OpenReminder',
-                                    Field => 'RT::Ticket',
-                                   NewValue => $reminder->id);
+    my ( $status, $msg ) = $reminder->SetStatus('open');
+    $self->TicketObj->_NewTransaction(
+        Type => 'OpenReminder',
+        Field => 'RT::Ticket',
+        NewValue => $reminder->id
+    ) if $status;
+    return ( $status, $msg );
 }
 
-
 sub Resolve {
     my $self = shift;
     my $reminder = shift;
-    $reminder->SetStatus('resolved');
-    $self->TicketObj->_NewTransaction(Type => 'ResolveReminder',
-                                    Field => 'RT::Ticket',
-                                   NewValue => $reminder->id);
+    my ( $status, $msg ) = $reminder->SetStatus('resolved');
+    $self->TicketObj->_NewTransaction(
+        Type => 'ResolveReminder',
+        Field => 'RT::Ticket',
+        NewValue => $reminder->id
+    ) if $status;
+    return ( $status, $msg );
 }
 
-    RT::Base->_ImportOverlays();
-
+RT::Base->_ImportOverlays();
 
 1;
