@@ -75,32 +75,28 @@
 package RT::Search;
 
 use strict;
+use warnings;
 
-# {{{ sub new 
-sub new  {
-  my $proto = shift;
-  my $class = ref($proto) || $proto;
-  my $self  = {};
-  bless ($self, $class);
-  $self->_Init(@_);
-  return $self;
+sub new {
+    my $proto = shift;
+    my $class = ref($proto) || $proto;
+    my $self  = {};
+    bless( $self, $class );
+    $self->_Init(@_);
+    return $self;
 }
-# }}}
 
-# {{{ sub _Init 
-sub _Init  {
-  my $self = shift;
-  my %args = ( 
-           TicketsObj => undef,
-	       Argument => undef,
-	       @_ );
-  
-  $self->{'TicketsObj'} = $args{'TicketsObj'}; 
-  $self->{'Argument'} = $args{'Argument'};
+sub _Init {
+    my $self = shift;
+    my %args = (
+        TicketsObj => undef,
+        Argument   => undef,
+        @_
+    );
+
+    $self->{'TicketsObj'} = $args{'TicketsObj'};
+    $self->{'Argument'}   = $args{'Argument'};
 }
-# }}}
-
-# {{{ sub Argument 
 
 =head2 Argument
 
@@ -108,14 +104,12 @@ Return the optional argument associated with this Search
 
 =cut
 
-sub Argument  {
-  my $self = shift;
-  return($self->{'Argument'});
+sub Argument {
+    my $self = shift;
+    return ( $self->{'Argument'} );
 }
-# }}}
 
-
-=head2 TicketsObj 
+=head2 TicketsObj
 
 Return the Tickets object passed into this search
 
@@ -123,22 +117,18 @@ Return the Tickets object passed into this search
 
 sub TicketsObj {
     my $self = shift;
-    return($self->{'TicketsObj'});
+    return ( $self->{'TicketsObj'} );
 }
 
-# {{{ sub Describe 
-sub Describe  {
-  my $self = shift;
-  return ($self->loc("No description for [_1]", ref $self));
+sub Describe {
+    my $self = shift;
+    return ( $self->loc( "No description for [_1]", ref $self ) );
 }
-# }}}
 
-# {{{ sub Prepare
-sub Prepare  {
-  my $self = shift;
-  return(1);
+sub Prepare {
+    my $self = shift;
+    return (1);
 }
-# }}}
 
 RT::Base->_ImportOverlays();
 
