@@ -113,11 +113,11 @@ sub __DependsOn
 
                 my $group_member = $args{'BaseObject'};
 
-                if( $group_member->MemberObj->id == $RT::Nobody->id ) {
+                if( $group_member->MemberObj->id == RT->Nobody->id ) {
                     RT::Shredder::Exception->throw( "Couldn't delete Nobody from owners role group" );
                 }
 
-                my( $status, $msg ) = $group->AddMember( $RT::Nobody->id );
+                my( $status, $msg ) = $group->AddMember( RT->Nobody->id );
                 RT::Shredder::Exception->throw( $msg ) unless $status;
 
                 my $ticket = RT::Ticket->new( $group->CurrentUser );
@@ -125,7 +125,7 @@ sub __DependsOn
                 RT::Shredder::Exception->throw( "Couldn't load ticket" ) unless $ticket->id;
 
                 ( $status, $msg ) = $ticket->_Set( Field => 'Owner',
-                                   Value => $RT::Nobody->id,
+                                   Value => RT->Nobody->id,
                                  );
                 RT::Shredder::Exception->throw( $msg ) unless $status;
 
