@@ -3,20 +3,15 @@
 use strict;
 use warnings;
 
-use File::Spec;
-use File::Temp 0.19 ();
-require File::Path;
 require File::Copy;
 require Cwd;
+require RT::Test;
 
 BEGIN {
 ### after:     push @INC, qw(@RT_LIB_PATH@);
 }
 use RT::Shredder;
 
-# where to keep temporary generated test data
-my $tmpdir = '';
-
 =head1 DESCRIPTION
 
 RT::Shredder test suite utilities
@@ -94,7 +89,7 @@ sub rewrite_rtconfig
     config_set( '$LogStackTraces' , 'crit' );
     # logging to standalone file
     config_set( '$LogToFile'      , 'debug' );
-    my $fname = File::Spec->catfile(create_tmpdir(), test_name() .".log");
+    my $fname = File::Spec->catfile(RT::Test->temp_directory(), test_name() .".log");
     config_set( '$LogToFileNamed' , $fname );
     config_set('@LexiconLanguages', qw(en));
 }
@@ -127,7 +122,7 @@ in most situations.
 
 sub init_db
 {
-    create_tmpdir();
+    RT::Test->bootstrap_tempdir() unless RT::Test->temp_directory();
     RT::LoadConfig();
     rewrite_rtconfig();
     RT::InitLogging();
@@ -161,13 +156,13 @@ sub _init_db
 =head3 db_name
 
 Returns the absolute file path to the current DB.
-It is <$tmpdir . test_name() .'.db'>.
+It is <<RT::Test->temp_directory . test_name() .'.db'>>.
 
 See also the C<test_name> function.
 
 =cut
 
-sub db_name { return File::Spec->catfile(create_tmpdir(), test_name() .".db") }
+sub db_name { return File::Spec->catfile(RT::Test->temp_directory(), test_name() .".db") }
 
 =head3 connect_sqlite
 
@@ -194,7 +189,7 @@ sub shredder_new
 {
     my $obj = RT::Shredder->new;
 
-    my $file = File::Spec->catfile( create_tmpdir(), test_name() .'.XXXX.sql' );
+    my $file = File::Spec->catfile( RT::Test->temp_directory, test_name() .'.XXXX.sql' );
     $obj->AddDumpPlugin( Arguments => {
         file_name    => $file,
         from_storage => 0,
@@ -223,44 +218,6 @@ sub test_name
     return $name;
 }
 
-=head2 TEMPORARY DIRECTORY
-
-=head3 tmpdir
-
-Returns the absolute path to a tmp dir used in tests.
-
-=cut
-
-sub tmpdir {
-    if (-d $tmpdir) {
-        return $tmpdir;
-    } else {
-        $tmpdir = File::Temp->newdir(TEMPLATE => 'shredderXXXXX', CLEANUP => 0);
-        return $tmpdir;
-    }
-}
-
-=head2 create_tmpdir
-
-Creates a tmp dir if one doesn't exist already. Returns tmpdir path.
-
-=cut
-
-sub create_tmpdir { my $n = tmpdir(); File::Path::mkpath( [$n] ); return $n }
-
-=head3 cleanup_tmp
-
-Deletes all the tmp dir used in the tests.
-See also the C<test_name> function.
-
-=cut
-
-sub cleanup_tmp
-{
-    my $dir = File::Spec->catdir(tmpdir(), test_name());
-    return File::Path::rmtree( File::Spec->catdir( tmpdir(), test_name() ));
-}
-
 =head2 SAVEPOINTS
 
 =head3 savepoint_name
@@ -273,7 +230,7 @@ Takes one argument - savepoint name, by default C<sp>.
 sub savepoint_name
 {
     my $name = shift || 'sp';
-    return File::Spec->catfile( create_tmpdir(), test_name() .".$name.db" );
+    return File::Spec->catfile( RT::Test->temp_directory, test_name() .".$name.db" );
 }
 
 =head3 create_savepoint
@@ -412,7 +369,7 @@ Returns a note about debug info that you can display if tests fail.
 sub note_on_fail
 {
     my $name = test_name();
-    my $tmpdir = tmpdir();
+    my $tmpdir = RT::Test->temp_directory();
     return <<END;
 Some tests in '$0' file failed.
 You can find debug info in '$tmpdir' dir.
@@ -424,27 +381,9 @@ See also perldoc t/shredder/utils.pl for how to use this info.
 END
 }
 
-=head2 OTHER
-
-=head3 all_were_successful
-
-Returns true if all tests that have already run were successful.
-
-=cut
-
-sub all_were_successful
-{
-    use Test::Builder;
-    my $Test = Test::Builder->new;
-    return grep( !$_, $Test->summary )? 0: 1;
-}
-
 END {
-    return unless -e tmpdir();
-    if ( all_were_successful() ) {
-            cleanup_tmp();
-    } else {
-            diag( note_on_fail() );
+    if ( ! RT::Test->builder->is_passing ) {
+        diag( note_on_fail() );
     }
 }
 
